==> scala-2.2.0.9025.tar.bz2: scala/Application.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: Application.scala 8756 2006-09-22 16:00:23Z michelou $


package scala


/** The <code>Application</code> class can be used to quickly turn objects
 *  into executable programs. Here is an example:
 *  <pre>
 *  <b>object</b> Main <b>extends</b> Application {
 *    Console.println("Hello World!")
 *  }
 *  </pre>
 *  Here, object <code>Main</code> inherits the <code>main</code> method
 *  of <code>Application</code>. The body of the <code>Main</code> object
 *  defines the main program. This technique does not work if the main
 *  program depends on command-line arguments (which are not accessible
 *  with the technique presented here).
 *
 *  It is possible to time the execution of objects that inherit from
 *  class <code>Application</code> by setting the global scala.time property.
 *  Here is an example for benchmarking object <code>Main</code>:
 *  <pre>
 *  java -Dscala.time Main
 *  </pre>
 *
 *  @author  Matthias Zenger
 *  @version 1.0, 10/09/2003
 */

trait Application {

  /** The time when execution of this program started.
   */
  val executionStart: Long = java.lang.System.currentTimeMillis()

  /** The default main method.
   *
   *  @param args the arguments passed to the main method
   */
  def main(args: Array[String]) = {
    if (java.lang.System.getProperty("scala.time") != null) {
      val total = java.lang.System.currentTimeMillis() - executionStart
      java.lang.System.out.println("[total " + total + "ms]")
    }
  }
}

==> scala-2.2.0.9153.tar.bz2: scala/Application.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: Application.scala 9110 2006-11-01 16:03:28Z mihaylov $


package scala


import compat.Platform.currentTime
import java.lang.System.getProperty

/** The <code>Application</code> class can be used to quickly turn objects
 *  into executable programs. Here is an example:
 *  <pre>
 *  <b>object</b> Main <b>extends</b> Application {
 *    Console.println("Hello World!")
 *  }
 *  </pre>
 *  Here, object <code>Main</code> inherits the <code>main</code> method
 *  of <code>Application</code>. The body of the <code>Main</code> object
 *  defines the main program. This technique does not work if the main
 *  program depends on command-line arguments (which are not accessible
 *  with the technique presented here).
 *
 *  It is possible to time the execution of objects that inherit from
 *  class <code>Application</code> by setting the global scala.time property.
 *  Here is an example for benchmarking object <code>Main</code>:
 *  <pre>
 *  java -Dscala.time Main
 *  </pre>
 *
 *  @author  Matthias Zenger
 *  @version 1.0, 10/09/2003
 */

trait Application {

  /** The time when execution of this program started.
   */
  val executionStart: Long = currentTime

  /** The default main method.
   *
   *  @param args the arguments passed to the main method
   */
  def main(args: Array[String]) = {
    if (getProperty("scala.time") != null) {
      val total = currentTime - executionStart
      Console.println("[total " + total + "ms]")
    }
  }
}
